@@ -47,27 +47,6 @@
 #include <fribidi.h>
 
 
-/**
- * SECTION:general
- * @Short_description: Library initialization and versioning
- * @Title: General
- *
- * This section describes miscellaneous macros and utility functions
- * related to library versioning, as well as deprecation facilities.
- *
- * The GDK and GTK headers annotate deprecated APIs in a way that produces
- * compiler warnings if these deprecated APIs are used. The warnings
- * can be turned off by defining the macro %GDK_DISABLE_DEPRECATION_WARNINGS
- * before including the glib.h header.
- *
- * GDK and GTK also provide support for building applications against
- * defined subsets of deprecated or new APIs. Define the macro
- * %GDK_VERSION_MIN_REQUIRED to specify up to what version
- * you want to receive warnings about deprecated APIs. Define the
- * macro %GDK_VERSION_MAX_ALLOWED to specify the newest version
- * whose API you want to use.
- */
-
 /**
  * GDK_WINDOWING_X11:
  *
@@ -173,7 +152,7 @@ stash_desktop_startup_notification_id (void)
       if (!g_utf8_validate (desktop_startup_id, -1, NULL))
         g_warning ("DESKTOP_STARTUP_ID contains invalid UTF-8");
       else
-        startup_notification_id = g_strdup (desktop_startup_id ? desktop_startup_id : "");
+        startup_notification_id = g_strdup (desktop_startup_id);
     }
 
   /* Clear the environment variable so it won't be inherited by
