@@ -1299,12 +1299,11 @@ gdk_surface_schedule_update (GdkSurface *surface)
 
   g_return_if_fail (surface);
 
+  surface->pending_phases |= GDK_FRAME_CLOCK_PHASE_PAINT;
+
   if (surface->update_freeze_count ||
       gdk_surface_is_toplevel_frozen (surface))
-    {
-      surface->pending_phases |= GDK_FRAME_CLOCK_PHASE_PAINT;
-      return;
-    }
+    return;
 
   /* If there's no frame clock (a foreign surface), then the invalid
    * region will just stick around unless gdk_surface_process_updates()
@@ -2444,6 +2443,7 @@ gdk_surface_ensure_motion (GdkSurface *surface)
   GdkEvent *event;
   double x, y;
   GdkModifierType state;
+  GdkSurface *grab_surface;
 
   if (!surface->request_motion)
     return;
@@ -2460,6 +2460,12 @@ gdk_surface_ensure_motion (GdkSurface *surface)
   if (!gdk_surface_get_device_position (surface, device, &x, &y, &state))
     return;
 
+  if (gdk_device_grab_info (display, device, &grab_surface, NULL))
+    {
+      if (grab_surface != surface)
+        return;
+    }
+
   event = gdk_motion_event_new (surface,
                                 device,
                                 NULL,
