@@ -28,6 +28,8 @@
 #include "gdkmacosdevice.h"
 #include "gdkmacosseat-private.h"
 
+#include "gdk-private.h"
+
 typedef struct
 {
   NSUInteger device_id;
@@ -622,6 +624,5 @@ _gdk_macos_seat_get_tablet_axes_from_nsevent (GdkMacosSeat *seat,
                                   [nsevent rotation], &tablet->axes[GDK_AXIS_ROTATION]);
     }
 
-  return g_memdup (tablet->axes,
-                   sizeof (double) * GDK_AXIS_LAST);
+  return g_memdup2 (tablet->axes, sizeof (double) * GDK_AXIS_LAST);
 }
