@@ -427,7 +427,12 @@ wintab_init_check (GdkDeviceManagerWin32 *device_manager)
 			    ndevices, ncursors));
 #endif
   /* Create a dummy window to receive wintab events */
-  wintab_window = gdk_surface_new_temp (display, &(GdkRectangle) { -100, -100, 2, 2 });
+  wintab_window =
+      _gdk_win32_display_create_surface (display,
+                                         GDK_SURFACE_TEMP,
+                                         NULL,
+                                         -100, -100, 2, 2);
+
   g_object_ref (wintab_window);
 
   for (devix = 0; devix < ndevices; devix++)
