@@ -503,7 +503,7 @@ on_registration_reply (GObject      *gobject,
     }
 
   /* Register the cache object */
-  self->cache = gtk_at_spi_cache_new (self->connection, ATSPI_CACHE_PATH);
+  self->cache = gtk_at_spi_cache_new (self->connection, ATSPI_CACHE_PATH, self);
 
   /* Drain the list of queued GtkAtSpiContexts, and add them to the cache */
   if (self->queued_contexts != NULL)
@@ -667,11 +667,21 @@ gtk_at_spi_root_constructed (GObject *gobject)
     {
       const char *program_name = g_get_prgname ();
 
+      char *base_name = NULL;
+      if (program_name == NULL || *program_name == 0)
+        base_name = g_strdup ("unknown");
+      else if (*program_name == '/')
+        base_name = g_path_get_basename (program_name);
+      else
+        base_name = g_strdup (program_name);
+
       self->base_path = g_strconcat ("/org/gtk/application/",
-                                     program_name != NULL ? program_name : "unknown",
+                                     base_name,
                                      "/a11y",
                                      NULL);
 
+      g_free (base_name);
+
       /* Turn potentially invalid program names into something that can be
        * used as a DBus path
        */
