@@ -70,7 +70,7 @@ struct _GtkColorEditor
   GtkWidget *picker_button;
   GtkColorPicker *picker;
 
-  gint popup_position;
+  int popup_position;
 
   guint text_changed : 1;
   guint use_alpha    : 1;
@@ -95,7 +95,7 @@ G_DEFINE_TYPE_WITH_CODE (GtkColorEditor, gtk_color_editor, GTK_TYPE_BOX,
                                                 gtk_color_editor_iface_init))
 
 static guint
-scale_round (gdouble value, gdouble scale)
+scale_round (double value, double scale)
 {
   value = floor (value * scale + 0.5);
   value = MAX (value, 0);
@@ -107,7 +107,7 @@ static void
 entry_set_rgba (GtkColorEditor *editor,
                 const GdkRGBA  *color)
 {
-  gchar *text;
+  char *text;
 
   text = g_strdup_printf ("#%02X%02X%02X",
                           scale_round (color->red, 255),
@@ -123,7 +123,7 @@ entry_apply (GtkWidget      *entry,
              GtkColorEditor *editor)
 {
   GdkRGBA color;
-  gchar *text;
+  char *text;
 
   if (!editor->text_changed)
     return;
@@ -161,7 +161,7 @@ static void
 hsv_changed (GtkColorEditor *editor)
 {
   GdkRGBA color;
-  gdouble h, s, v, a;
+  double h, s, v, a;
 
   h = gtk_adjustment_get_value (editor->h_adj);
   s = gtk_adjustment_get_value (editor->s_adj);
@@ -204,8 +204,8 @@ popup_edit (GtkWidget  *widget,
   GtkWidget *popup = NULL;
   GtkRoot *root;
   GtkWidget *focus;
-  gint position;
-  gint s, e;
+  int position;
+  int s, e;
   const char *param;
 
   param = g_variant_get_string (parameters, NULL);
@@ -273,7 +273,7 @@ get_child_position (GtkOverlay     *overlay,
 {
   GtkRequisition req;
   GtkAllocation alloc;
-  gint s, e;
+  int s, e;
   double x, y;
 
   gtk_widget_get_preferred_size (widget, &req, NULL);
@@ -333,7 +333,7 @@ static void
 value_changed (GtkAdjustment *a,
                GtkAdjustment *as)
 {
-  gdouble scale;
+  double scale;
 
   scale = gtk_adjustment_get_upper (as) / gtk_adjustment_get_upper (a);
   g_signal_handlers_block_by_func (as, value_changed, a);
@@ -343,7 +343,7 @@ value_changed (GtkAdjustment *a,
 
 static GtkAdjustment *
 scaled_adjustment (GtkAdjustment *a,
-                   gdouble        scale)
+                   double         scale)
 {
   GtkAdjustment *as;
 
