@@ -24,9 +24,7 @@
 #include "gtkstyleproviderprivate.h"
 #include "gtksettingsprivate.h"
 
-#ifdef _MSC_VER
-# include <intrin.h>
-#endif
+#include "gtkpopcountprivate.h"
 
 /* repeated API */
 
@@ -547,57 +545,6 @@ _gtk_css_font_stretch_value_get (const GtkCssValue *value)
   return value->value;
 }
 
-/* GtkTextDecorationLine */
-
-static const GtkCssValueClass GTK_CSS_VALUE_TEXT_DECORATION_LINE = {
-  "GtkCssTextDecorationLineValue",
-  gtk_css_value_enum_free,
-  gtk_css_value_enum_compute,
-  gtk_css_value_enum_equal,
-  gtk_css_value_enum_transition,
-  NULL,
-  NULL,
-  gtk_css_value_enum_print
-};
-
-static GtkCssValue text_decoration_line_values[] = {
-  { &GTK_CSS_VALUE_TEXT_DECORATION_LINE, 1, TRUE, GTK_CSS_TEXT_DECORATION_LINE_NONE, "none" },
-  { &GTK_CSS_VALUE_TEXT_DECORATION_LINE, 1, TRUE, GTK_CSS_TEXT_DECORATION_LINE_UNDERLINE, "underline" },
-  { &GTK_CSS_VALUE_TEXT_DECORATION_LINE, 1, TRUE, GTK_CSS_TEXT_DECORATION_LINE_LINE_THROUGH, "line-through" },
-};
-
-GtkCssValue *
-_gtk_css_text_decoration_line_value_new (GtkTextDecorationLine line)
-{
-  g_return_val_if_fail (line < G_N_ELEMENTS (text_decoration_line_values), NULL);
-
-  return _gtk_css_value_ref (&text_decoration_line_values[line]);
-}
-
-GtkCssValue *
-_gtk_css_text_decoration_line_value_try_parse (GtkCssParser *parser)
-{
-  guint i;
-
-  g_return_val_if_fail (parser != NULL, NULL);
-
-  for (i = 0; i < G_N_ELEMENTS (text_decoration_line_values); i++)
-    {
-      if (gtk_css_parser_try_ident (parser, text_decoration_line_values[i].name))
-        return _gtk_css_value_ref (&text_decoration_line_values[i]);
-    }
-
-  return NULL;
-}
-
-GtkTextDecorationLine
-_gtk_css_text_decoration_line_value_get (const GtkCssValue *value)
-{
-  g_return_val_if_fail (value->class == &GTK_CSS_VALUE_TEXT_DECORATION_LINE, GTK_CSS_TEXT_DECORATION_LINE_NONE);
-
-  return value->value;
-}
-
 /* GtkTextDecorationStyle */
 
 static const GtkCssValueClass GTK_CSS_VALUE_TEXT_DECORATION_STYLE = {
@@ -1205,6 +1152,99 @@ gtk_css_value_flags_print (const FlagsValue  *values,
     }
 }
 
+/* GtkTextDecorationLine */
+
+static FlagsValue text_decoration_line_values[] = {
+  { GTK_CSS_TEXT_DECORATION_LINE_NONE, "none" },
+  { GTK_CSS_TEXT_DECORATION_LINE_UNDERLINE, "underline" },
+  { GTK_CSS_TEXT_DECORATION_LINE_OVERLINE, "overline" },
+  { GTK_CSS_TEXT_DECORATION_LINE_LINE_THROUGH, "line-through" },
+};
+
+static void
+gtk_css_text_decoration_line_value_print (const GtkCssValue *value,
+                                          GString           *string)
+{
+  gtk_css_value_flags_print (text_decoration_line_values,
+                             G_N_ELEMENTS (text_decoration_line_values),
+                             value, string);
+}
+
+static const GtkCssValueClass GTK_CSS_VALUE_TEXT_DECORATION_LINE = {
+  "GtkCssTextDecorationLine",
+  gtk_css_value_enum_free,
+  gtk_css_value_enum_compute,
+  gtk_css_value_flags_equal,
+  gtk_css_value_enum_transition,
+  NULL,
+  NULL,
+  gtk_css_text_decoration_line_value_print
+};
+
+static gboolean
+text_decoration_line_is_valid (GtkTextDecorationLine line)
+{
+  if ((line & GTK_CSS_TEXT_DECORATION_LINE_NONE) &&
+      (line != GTK_CSS_TEXT_DECORATION_LINE_NONE))
+    return FALSE;
+
+  return TRUE;
+}
+
+GtkCssValue *
+_gtk_css_text_decoration_line_value_new (GtkTextDecorationLine line)
+{
+  GtkCssValue *value;
+
+  if (!text_decoration_line_is_valid (line))
+    return NULL;
+
+  value = _gtk_css_value_new (GtkCssValue, &GTK_CSS_VALUE_TEXT_DECORATION_LINE);
+  value->value = line;
+  value->name = NULL;
+  value->is_computed = TRUE;
+
+  return value;
+}
+
+GtkTextDecorationLine
+_gtk_css_text_decoration_line_try_parse_one (GtkCssParser          *parser,
+                                             GtkTextDecorationLine  base)
+{
+  guint i;
+  GtkTextDecorationLine value = 0;
+
+  g_return_val_if_fail (parser != NULL, 0);
+
+  for (i = 0; i < G_N_ELEMENTS (text_decoration_line_values); i++)
+    {
+      if (gtk_css_parser_try_ident (parser, text_decoration_line_values[i].name))
+        {
+          value = text_decoration_line_values[i].value;
+          break;
+        }
+    }
+
+  if (value == 0)
+    return base; /* not parsing this value */
+
+  if ((base | value) == base)
+    return 0; /* repeated value */
+
+  if (!text_decoration_line_is_valid (base | value))
+    return 0; /* bad combination */
+
+  return base | value;
+}
+
+GtkTextDecorationLine
+_gtk_css_text_decoration_line_value_get (const GtkCssValue *value)
+{
+  g_return_val_if_fail (value->class == &GTK_CSS_VALUE_TEXT_DECORATION_LINE, GTK_CSS_TEXT_DECORATION_LINE_NONE);
+
+  return value->value;
+}
+
 /* GtkCssFontVariantLigature */
 
 static FlagsValue font_variant_ligature_values[] = {
@@ -1453,39 +1493,6 @@ static const GtkCssValueClass GTK_CSS_VALUE_FONT_VARIANT_EAST_ASIAN = {
   gtk_css_font_variant_east_asian_value_print
 };
 
-#ifdef _MSC_VER
-/* __builtin_popcount is a GCC-only function
-   so we need to define it for ourselves somehow */
-
-static inline guint
-__msvc_compat_popcnt (guint32 value)
-{
-  static gssize popcnt_checked = 0;
-  static gboolean have_popcnt = FALSE;
-
-# if defined (_M_AMD64) || defined (_M_X64) || (_M_IX86)
-  if (g_once_init_enter (&popcnt_checked))
-    {
-      int cpuinfo[4] = {-1};
-
-	  __cpuid (cpuinfo, 1);
-      have_popcnt =  (cpuinfo[2] & 0x00800000) != 0;
-      g_once_init_leave (&popcnt_checked, 1);
-    }
-# endif
-
-  if (have_popcnt)
-    return __popcnt (value);
-  else
-    /* http://graphics.stanford.edu/~seander/bithacks.html#CountBitsSetParallel */
-    return (((value & 0xfff) * 0x1001001001001ULL & 0x84210842108421ULL) % 0x1f) +
-           ((((value & 0xfff000) >> 12) * 0x1001001001001ULL & 0x84210842108421ULL) % 0x1f) +
-           (((value >> 24) * 0x1001001001001ULL & 0x84210842108421ULL) % 0x1f);
-}
-
-# define __builtin_popcount(v) __msvc_compat_popcnt(v)
-#endif
-
 static gboolean
 east_asian_value_is_valid (GtkCssFontVariantEastAsian east_asian)
 {
@@ -1493,16 +1500,16 @@ east_asian_value_is_valid (GtkCssFontVariantEastAsian east_asian)
       (east_asian != GTK_CSS_FONT_VARIANT_EAST_ASIAN_NORMAL))
     return FALSE;
 
-  if (__builtin_popcount (east_asian & (GTK_CSS_FONT_VARIANT_EAST_ASIAN_JIS78 |
-                                        GTK_CSS_FONT_VARIANT_EAST_ASIAN_JIS83 |
-                                        GTK_CSS_FONT_VARIANT_EAST_ASIAN_JIS90 |
-                                        GTK_CSS_FONT_VARIANT_EAST_ASIAN_JIS04 |
-                                        GTK_CSS_FONT_VARIANT_EAST_ASIAN_SIMPLIFIED |
-                                        GTK_CSS_FONT_VARIANT_EAST_ASIAN_TRADITIONAL)) > 1)
+  if (gtk_popcount (east_asian & (GTK_CSS_FONT_VARIANT_EAST_ASIAN_JIS78 |
+                                  GTK_CSS_FONT_VARIANT_EAST_ASIAN_JIS83 |
+                                  GTK_CSS_FONT_VARIANT_EAST_ASIAN_JIS90 |
+                                  GTK_CSS_FONT_VARIANT_EAST_ASIAN_JIS04 |
+                                  GTK_CSS_FONT_VARIANT_EAST_ASIAN_SIMPLIFIED |
+                                  GTK_CSS_FONT_VARIANT_EAST_ASIAN_TRADITIONAL)) > 1)
     return FALSE;
 
-  if (__builtin_popcount (east_asian & (GTK_CSS_FONT_VARIANT_EAST_ASIAN_FULL_WIDTH |
-                                        GTK_CSS_FONT_VARIANT_EAST_ASIAN_PROPORTIONAL)) > 1)
+  if (gtk_popcount (east_asian & (GTK_CSS_FONT_VARIANT_EAST_ASIAN_FULL_WIDTH |
+                                  GTK_CSS_FONT_VARIANT_EAST_ASIAN_PROPORTIONAL)) > 1)
     return FALSE;
 
   return TRUE;
