@@ -447,9 +447,10 @@ _gtk_file_consider_as_remote (GFile *file)
 }
 
 GIcon *
-_gtk_file_info_get_icon (GFileInfo *info,
-                         int        icon_size,
-                         int        scale)
+_gtk_file_info_get_icon (GFileInfo    *info,
+                         int           icon_size,
+                         int           scale,
+                         GtkIconTheme *icon_theme)
 {
   GIcon *icon;
   GdkPixbuf *pixbuf;
@@ -468,7 +469,7 @@ _gtk_file_info_get_icon (GFileInfo *info,
     }
 
   icon = g_file_info_get_icon (info);
-  if (icon)
+  if (icon && gtk_icon_theme_has_gicon (icon_theme, icon))
     return g_object_ref (icon);
 
   /* Use general fallback for all files without icon */
