@@ -56,17 +56,20 @@ struct _GtkFontChooserDialogClass
 };
 
 /**
- * SECTION:gtkfontchooserdialog
- * @Short_description: A dialog for selecting fonts
- * @Title: GtkFontChooserDialog
- * @See_also: #GtkFontChooser, #GtkDialog
+ * GtkFontChooserDialog:
  *
- * The #GtkFontChooserDialog widget is a dialog for selecting a font.
- * It implements the #GtkFontChooser interface.
+ * The `GtkFontChooserDialog` widget is a dialog for selecting a font.
+ *
+ * ![An example GtkFontChooserDialog](fontchooser.png)
+ *
+ * `GtkFontChooserDialog` implements the [iface@Gtk.FontChooser] interface
+ * and does not provide much API of its own.
+ *
+ * To create a `GtkFontChooserDialog`, use [ctor@Gtk.FontChooserDialog.new].
  *
  * # GtkFontChooserDialog as GtkBuildable
  *
- * The GtkFontChooserDialog implementation of the #GtkBuildable
+ * The `GtkFontChooserDialog` implementation of the `GtkBuildable`
  * interface exposes the buttons with the names “select_button”
  * and “cancel_button”.
  */
@@ -183,6 +186,8 @@ setup_tweak_button (GtkFontChooserDialog *dialog)
       gtk_header_bar_pack_end (GTK_HEADER_BAR (header), button);
 
       dialog->tweak_button = button;
+
+      update_tweak_button (dialog);
     }
 }
 
@@ -279,9 +284,9 @@ gtk_font_chooser_dialog_init (GtkFontChooserDialog *dialog)
  * @title: (allow-none): Title of the dialog, or %NULL
  * @parent: (allow-none): Transient parent of the dialog, or %NULL
  *
- * Creates a new #GtkFontChooserDialog.
+ * Creates a new `GtkFontChooserDialog`.
  *
- * Returns: a new #GtkFontChooserDialog
+ * Returns: a new `GtkFontChooserDialog`
  */
 GtkWidget*
 gtk_font_chooser_dialog_new (const char *title,
