@@ -550,7 +550,7 @@ populate_servers (GtkPlacesView *view)
 
   /* clear previous items */
   while ((child = gtk_widget_get_first_child (GTK_WIDGET (view->recent_servers_listbox))))
-    gtk_list_box_remove (GTK_LIST_BOX (view->listbox), child);
+    gtk_list_box_remove (GTK_LIST_BOX (view->recent_servers_listbox), child);
 
   gtk_list_store_clear (view->completion_store);
 
@@ -1215,12 +1215,14 @@ server_mount_ready_cb (GObject      *source_file,
       g_clear_error (&error);
     }
 
-  if (view->destroyed) {
-    g_object_unref (view);
-    return;
-  }
+  if (view->destroyed)
+    {
+      g_object_unref (view);
+      return;
+    }
 
   view->should_pulse_entry = FALSE;
+  gtk_entry_set_progress_fraction (GTK_ENTRY (view->address_entry), 0);
 
   /* Restore from Cancel to Connect */
   gtk_button_set_label (GTK_BUTTON (view->connect_button), _("Con_nect"));
@@ -1243,6 +1245,11 @@ server_mount_ready_cb (GObject      *source_file,
           GMount *mount;
           GFile *root;
 
+          /*
+           * If the mount is not found at this point, it is probably user-
+           * invisible, which happens e.g for smb-browse, but the location
+           * should be opened anyway...
+           */
           mount = g_file_find_enclosing_mount (location, view->cancellable, NULL);
           if (mount)
             {
@@ -1253,6 +1260,10 @@ server_mount_ready_cb (GObject      *source_file,
               g_object_unref (root);
               g_object_unref (mount);
             }
+          else
+            {
+              emit_open_location (view, location, view->open_flags);
+            }
         }
     }
 
@@ -1388,8 +1399,7 @@ pulse_entry_cb (gpointer user_data)
     }
   else
     {
-      gtk_entry_set_progress_pulse_step (GTK_ENTRY (view->address_entry), 0.0);
-      gtk_entry_set_progress_fraction (GTK_ENTRY (view->address_entry), 0.0);
+      gtk_entry_set_progress_fraction (GTK_ENTRY (view->address_entry), 0);
       view->entry_pulse_timeout_id = 0;
 
       return G_SOURCE_REMOVE;
@@ -1443,6 +1453,7 @@ mount_server (GtkPlacesView *view,
 
   view->should_pulse_entry = TRUE;
   gtk_entry_set_progress_pulse_step (GTK_ENTRY (view->address_entry), 0.1);
+  gtk_entry_set_progress_fraction (GTK_ENTRY (view->address_entry), 0.1);
   /* Allow to cancel the operation */
   gtk_button_set_label (GTK_BUTTON (view->connect_button), _("Cance_l"));
   gtk_widget_set_sensitive (view->address_entry, FALSE);
