@@ -19,28 +19,27 @@
  */
 
 /**
- * SECTION:gtkpopovermenubar
- * @Title: GtkPopoverMenuBar
- * @Short_description: A menu bar with popovers
- * @See_also: #GtkPopover, #GtkPopoverMenu, #GMenuModel
+ * GtkPopoverMenuBar:
  *
- * GtkPopoverMenuBar presents a horizontal bar of items that pop
+ * `GtkPopoverMenuBar` presents a horizontal bar of items that pop
  * up popover menus when clicked.
  *
- * The only way to create instances of GtkPopoverMenuBar is
- * from a #GMenuModel.
+ * ![An example GtkPopoverMenuBar](menubar.png)
+ *
+ * The only way to create instances of `GtkPopoverMenuBar` is
+ * from a `GMenuModel`.
  *
  * # CSS nodes
  *
- * |[<!-- language="plain" -->
+ * ```
  * menubar
  * ├── item[.active]
  * ┊   ╰── popover
  * ╰── item
  *     ╰── popover
- * ]|
+ * ```
  *
- * GtkPopoverMenuBar has a single CSS node with name menubar, below which
+ * `GtkPopoverMenuBar` has a single CSS node with name menubar, below which
  * each item has its CSS node, and below that the corresponding popover.
  *
  * The item whose popover is currently open gets the .active
@@ -48,9 +47,9 @@
  *
  * # Accessibility
  *
- * GtkPopoverMenuBar uses the #GTK_ACCESSIBLE_ROLE_MENU_BAR role,
- * the menu items use the #GTK_ACCESSIBLE_ROLE_MENU_ITEM role and
- * the menus use the #GTK_ACCESSIBLE_ROLE_MENU role.
+ * `GtkPopoverMenuBar` uses the %GTK_ACCESSIBLE_ROLE_MENU_BAR role,
+ * the menu items use the %GTK_ACCESSIBLE_ROLE_MENU_ITEM role and
+ * the menus use the %GTK_ACCESSIBLE_ROLE_MENU role.
  */
 
 
@@ -320,7 +319,7 @@ gtk_popover_menu_bar_item_size_allocate (GtkWidget *widget,
                             &(GtkAllocation) { 0, 0, width, height },
                             baseline);
 
-  gtk_native_check_resize (GTK_NATIVE (item->popover));
+  gtk_popover_present (GTK_POPOVER (item->popover));
 }
 
 static void
@@ -341,8 +340,8 @@ gtk_popover_menu_bar_item_root (GtkWidget *widget)
   GTK_WIDGET_CLASS (gtk_popover_menu_bar_item_parent_class)->root (widget);
 
   gtk_accessible_update_relation (GTK_ACCESSIBLE (widget),
-                                  GTK_ACCESSIBLE_RELATION_LABELLED_BY, g_list_append (NULL, item->label),
-                                  GTK_ACCESSIBLE_RELATION_CONTROLS, g_list_append (NULL, item->popover),
+                                  GTK_ACCESSIBLE_RELATION_LABELLED_BY, item->label, NULL,
+                                  GTK_ACCESSIBLE_RELATION_CONTROLS, item->popover, NULL,
                                   -1);
   gtk_accessible_update_property (GTK_ACCESSIBLE (widget),
                                   GTK_ACCESSIBLE_PROPERTY_HAS_POPUP, TRUE,
@@ -354,6 +353,7 @@ gtk_popover_menu_bar_item_class_init (GtkPopoverMenuBarItemClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
+  guint activate_signal;
 
   object_class->dispose = gtk_popover_menu_bar_item_dispose;
   object_class->finalize = gtk_popover_menu_bar_item_finalize;
@@ -364,7 +364,7 @@ gtk_popover_menu_bar_item_class_init (GtkPopoverMenuBarItemClass *klass)
 
   klass->activate = gtk_popover_menu_bar_item_activate;
 
-  widget_class->activate_signal =
+  activate_signal =
     g_signal_new (I_("activate"),
                   G_OBJECT_CLASS_TYPE (object_class),
                   G_SIGNAL_RUN_FIRST,
@@ -375,6 +375,7 @@ gtk_popover_menu_bar_item_class_init (GtkPopoverMenuBarItemClass *klass)
 
   gtk_widget_class_set_css_name (widget_class, I_("item"));
   gtk_widget_class_set_accessible_role (widget_class, GTK_ACCESSIBLE_ROLE_MENU_ITEM);
+  gtk_widget_class_set_activate_signal (widget_class, activate_signal);
 }
 enum
 {
@@ -624,9 +625,9 @@ gtk_popover_menu_bar_class_init (GtkPopoverMenuBarClass *klass)
   widget_class->focus = gtk_popover_menu_bar_focus;
 
   /**
-   * GtkPopoverMenuBar:menu-model:
+   * GtkPopoverMenuBar:menu-model: (attributes org.gtk.Property.get=gtk_popover_menu_bar_get_menu_model org.gtk.Property.set=gtk_popover_menu_bar_set_menu_model)
    *
-   * The #GMenuModel from which the menu bar is created.
+   * The `GMenuModel` from which the menu bar is created.
    *
    * The model should only contain submenus as toplevel elements.
    */
@@ -682,11 +683,11 @@ gtk_popover_menu_bar_buildable_iface_init (GtkBuildableIface *iface)
 
 /**
  * gtk_popover_menu_bar_new_from_model:
- * @model: (allow-none): a #GMenuModel, or %NULL
+ * @model: (allow-none): a `GMenuModel`, or %NULL
  *
- * Creates a #GtkPopoverMenuBar from a #GMenuModel.
+ * Creates a `GtkPopoverMenuBar` from a `GMenuModel`.
  *
- * Returns: a new #GtkPopoverMenuBar
+ * Returns: a new `GtkPopoverMenuBar`
  */
 GtkWidget *
 gtk_popover_menu_bar_new_from_model (GMenuModel *model)
@@ -697,9 +698,9 @@ gtk_popover_menu_bar_new_from_model (GMenuModel *model)
 }
 
 /**
- * gtk_popover_menu_bar_set_menu_model:
- * @bar: a #GtkPopoverMenuBar
- * @model: (allow-none): a #GMenuModel, or %NULL
+ * gtk_popover_menu_bar_set_menu_model: (attributes org.gtk.Method.set_property=menu-model)
+ * @bar: a `GtkPopoverMenuBar`
+ * @model: (allow-none): a `GMenuModel`, or %NULL
  *
  * Sets a menu model from which @bar should take
  * its contents.
@@ -740,12 +741,12 @@ gtk_popover_menu_bar_set_menu_model (GtkPopoverMenuBar *bar,
 }
 
 /**
- * gtk_popover_menu_bar_get_menu_model:
- * @bar: a #GtkPopoverMenuBar
+ * gtk_popover_menu_bar_get_menu_model: (attributes org.gtk.Method.get_property=menu-model)
+ * @bar: a `GtkPopoverMenuBar`
  *
  * Returns the model from which the contents of @bar are taken.
  *
- * Returns: (transfer none): a #GMenuModel
+ * Returns: (transfer none): a `GMenuModel`
  */
 GMenuModel *
 gtk_popover_menu_bar_get_menu_model (GtkPopoverMenuBar *bar)
@@ -766,8 +767,8 @@ gtk_popover_menu_bar_select_first (GtkPopoverMenuBar *bar)
 
 /**
  * gtk_popover_menu_bar_add_child:
- * @bar: a #GtkPopoverMenuBar
- * @child: the #GtkWidget to add
+ * @bar: a `GtkPopoverMenuBar`
+ * @child: the `GtkWidget` to add
  * @id: the ID to insert @child at
  *
  * Adds a custom widget to a generated menubar.
@@ -803,7 +804,7 @@ gtk_popover_menu_bar_add_child (GtkPopoverMenuBar *bar,
 
 /**
  * gtk_popover_menu_bar_remove_child:
- * @bar: a #GtkPopoverMenuBar
+ * @bar: a `GtkPopoverMenuBar`
  * @child: the #GtkWidget to remove
  *
  * Removes a widget that has previously been added with
@@ -832,4 +833,3 @@ gtk_popover_menu_bar_remove_child (GtkPopoverMenuBar *bar,
 
   return FALSE;
 }
-
