@@ -460,7 +460,7 @@ gtk_single_selection_new (GListModel *model)
 {
   GtkSingleSelection *self;
 
-  g_return_val_if_fail (G_IS_LIST_MODEL (model), NULL);
+  g_return_val_if_fail (model == NULL || G_IS_LIST_MODEL (model), NULL);
 
   self = g_object_new (GTK_TYPE_SINGLE_SELECTION,
                        "model", model,
