@@ -699,6 +699,9 @@ gtk_distribute_natural_allocation (int               extra_space,
 
   g_return_val_if_fail (extra_space >= 0, 0);
 
+  if (n_requested_sizes == 0)
+    return extra_space;
+
   spreading = g_newa (guint, n_requested_sizes);
 
   for (i = 0; i < n_requested_sizes; i++)
