@@ -23,10 +23,9 @@
 
 
 /**
- * SECTION:gtktreesortable
- * @Short_description: The interface for sortable models used by GtkTreeView
- * @Title: GtkTreeSortable
- * @See_also:#GtkTreeModel, #GtkTreeView
+ * GtkTreeSortable:
+ *
+ * The interface for sortable models used by GtkTreeView
  *
  * #GtkTreeSortable is an interface to be implemented by tree models which
  * support sorting. The #GtkTreeView uses the methods provided by this interface
@@ -122,7 +121,7 @@ gtk_tree_sortable_sort_column_changed (GtkTreeSortable *sortable)
  **/
 gboolean
 gtk_tree_sortable_get_sort_column_id (GtkTreeSortable  *sortable,
-				      gint             *sort_column_id,
+				      int              *sort_column_id,
 				      GtkSortType      *order)
 {
   GtkTreeSortableIface *iface;
@@ -155,7 +154,7 @@ gtk_tree_sortable_get_sort_column_id (GtkTreeSortable  *sortable,
  */
 void
 gtk_tree_sortable_set_sort_column_id (GtkTreeSortable  *sortable,
-				      gint              sort_column_id,
+				      int               sort_column_id,
 				      GtkSortType       order)
 {
   GtkTreeSortableIface *iface;
@@ -184,7 +183,7 @@ gtk_tree_sortable_set_sort_column_id (GtkTreeSortable  *sortable,
  */
 void
 gtk_tree_sortable_set_sort_func (GtkTreeSortable        *sortable,
-				 gint                    sort_column_id,
+				 int                     sort_column_id,
 				 GtkTreeIterCompareFunc  sort_func,
 				 gpointer                user_data,
 				 GDestroyNotify          destroy)
