@@ -35,6 +35,8 @@
 #include <gst/gl/wayland/gstgldisplay_wayland.h>
 #endif
 
+#include <gst/gl/gstglfuncs.h>
+
 enum {
   PROP_0,
   PROP_PAINTABLE,
@@ -172,6 +174,7 @@ gtk_gst_sink_propose_allocation (GstBaseSink *bsink,
   GstCaps *caps;
   guint size;
   gboolean need_pool;
+  GstVideoInfo info;
 
   if (!self->gst_context)
     return FALSE;
@@ -187,24 +190,23 @@ gtk_gst_sink_propose_allocation (GstBaseSink *bsink,
   if (!gst_caps_features_contains (gst_caps_get_features (caps, 0), GST_CAPS_FEATURE_MEMORY_GL_MEMORY))
     return FALSE;
 
+  if (!gst_video_info_from_caps (&info, caps))
+    {
+      GST_DEBUG_OBJECT (self, "invalid caps specified");
+      return FALSE;
+    }
+
+  /* the normal size of a frame */
+  size = info.size;
+
   if (need_pool)
     {
-      GstVideoInfo info;
-
-      if (!gst_video_info_from_caps (&info, caps))
-        {
-          GST_DEBUG_OBJECT (self, "invalid caps specified");
-          return FALSE;
-        }
-
       GST_DEBUG_OBJECT (self, "create new pool");
       pool = gst_gl_buffer_pool_new (self->gst_context);
 
-      /* the normal size of a frame */
-      size = info.size;
-
       config = gst_buffer_pool_get_config (pool);
       gst_buffer_pool_config_set_params (config, caps, size, 0, 0);
+      gst_buffer_pool_config_add_option (config, GST_BUFFER_POOL_OPTION_GL_SYNC_META);
 
       if (!gst_buffer_pool_set_config (pool, config))
         {
@@ -212,15 +214,19 @@ gtk_gst_sink_propose_allocation (GstBaseSink *bsink,
           gst_object_unref (pool);
           return FALSE;
         }
-
-      /* we need at least 2 buffer because we hold on to the last one */
-      gst_query_add_allocation_pool (query, pool, size, 2, 0);
-      gst_object_unref (pool);
     }
 
+  /* we need at least 2 buffer because we hold on to the last one */
+  gst_query_add_allocation_pool (query, pool, size, 2, 0);
+  if (pool)
+    gst_object_unref (pool);
+
   /* we also support various metadata */
   gst_query_add_allocation_meta (query, GST_VIDEO_META_API_TYPE, 0);
 
+  if (self->gst_context->gl_vtable->FenceSync)
+    gst_query_add_allocation_meta (query, GST_GL_SYNC_META_API_TYPE, 0);
+
   return TRUE;
 }
 
@@ -259,44 +265,51 @@ gtk_gst_sink_texture_from_buffer (GtkGstSink *self,
                                   GstBuffer  *buffer,
                                   double     *pixel_aspect_ratio)
 {
-  GstVideoFrame frame;
+  GstVideoFrame *frame = g_new (GstVideoFrame, 1);
   GdkTexture *texture;
 
   if (self->gdk_context &&
-      gst_video_frame_map (&frame, &self->v_info, buffer, GST_MAP_READ | GST_MAP_GL))
+      gst_video_frame_map (frame, &self->v_info, buffer, GST_MAP_READ | GST_MAP_GL))
     {
+      GstGLSyncMeta *sync_meta;
+
+      sync_meta = gst_buffer_get_gl_sync_meta (buffer);
+      if (sync_meta) {
+        gst_gl_sync_meta_set_sync_point (sync_meta, self->gst_context);
+        gst_gl_sync_meta_wait (sync_meta, self->gst_context);
+      }
+
       texture = gdk_gl_texture_new (self->gdk_context,
-                                    *(guint *) frame.data[0],
-                                    frame.info.width,
-                                    frame.info.height,
-                                    (GDestroyNotify) gst_buffer_unref,
-                                    gst_buffer_ref (buffer));
+                                    *(guint *) frame->data[0],
+                                    frame->info.width,
+                                    frame->info.height,
+                                    (GDestroyNotify) video_frame_free,
+                                    frame);
 
-     *pixel_aspect_ratio = ((double) frame.info.par_n) / ((double) frame.info.par_d);
-
-      gst_video_frame_unmap (&frame);
+      *pixel_aspect_ratio = ((double) frame->info.par_n) / ((double) frame->info.par_d);
     }
-  else if (gst_video_frame_map (&frame, &self->v_info, buffer, GST_MAP_READ))
+  else if (gst_video_frame_map (frame, &self->v_info, buffer, GST_MAP_READ))
     {
       GBytes *bytes;
 
-      bytes = g_bytes_new_with_free_func (frame.data[0],
-                                          frame.info.height * frame.info.stride[0],
+      bytes = g_bytes_new_with_free_func (frame->data[0],
+                                          frame->info.height * frame->info.stride[0],
                                           (GDestroyNotify) video_frame_free,
-                                          g_memdup (&frame, sizeof (frame)));
-      texture = gdk_memory_texture_new (frame.info.width,
-                                        frame.info.height,
-                                        gtk_gst_memory_format_from_video (GST_VIDEO_FRAME_FORMAT (&frame)),
+                                          frame);
+      texture = gdk_memory_texture_new (frame->info.width,
+                                        frame->info.height,
+                                        gtk_gst_memory_format_from_video (GST_VIDEO_FRAME_FORMAT (frame)),
                                         bytes,
-                                        frame.info.stride[0]);
+                                        frame->info.stride[0]);
       g_bytes_unref (bytes);
 
-     *pixel_aspect_ratio = ((double) frame.info.par_n) / ((double) frame.info.par_d);
+      *pixel_aspect_ratio = ((double) frame->info.par_n) / ((double) frame->info.par_d);
     }
   else
     {
       GST_ERROR_OBJECT (self, "Could not convert buffer to texture.");
       texture = NULL;
+      g_free (frame);
     }
 
   return texture;
