@@ -21,6 +21,7 @@
 #include <string.h>
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
+#include "testsuite/testutils.h"
 
 #ifdef G_OS_WIN32
 # include <io.h>
@@ -50,51 +51,6 @@ test_get_other_file (const char *ui_file, const char *extension)
   return g_string_free (file, FALSE);
 }
 
-static GBytes *
-diff_with_file (const char  *file1,
-                char        *text,
-                gssize       len,
-                GError     **error)
-{
-  GSubprocess *process;
-  GBytes *input, *output;
-
-  process = g_subprocess_new (G_SUBPROCESS_FLAGS_STDIN_PIPE
-                              | G_SUBPROCESS_FLAGS_STDOUT_PIPE,
-                              error,
-                              "diff", "-u", file1, "-", NULL);
-  if (process == NULL)
-    return NULL;
-
-  input = g_bytes_new_static (text, len >= 0 ? len : strlen (text));
-  if (!g_subprocess_communicate (process,
-                                 input,
-                                 NULL,
-                                 &output,
-                                 NULL,
-                                 error))
-    {
-      g_object_unref (process);
-      g_bytes_unref (input);
-      return NULL;
-    }
-
-  if (!g_subprocess_get_successful (process) &&
-      /* this is the condition when the files differ */
-      !(g_subprocess_get_if_exited (process) && g_subprocess_get_exit_status (process) == 1))
-    {
-      g_clear_pointer (&output, g_bytes_unref);
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-                   "The `diff' process exited with error status %d",
-                   g_subprocess_get_exit_status (process));
-    }
-
-  g_object_unref (process);
-  g_bytes_unref (input);
-
-  return output;
-}
-
 static char *
 fixup_style_differences (const char *str)
 {
@@ -133,7 +89,7 @@ load_ui_file (GFile *file, gboolean generate)
   GtkBuilder *builder;
   GtkWidget *window;
   char *output;
-  GBytes *diff;
+  char *diff;
   char *ui_file, *css_file, *reference_file;
   GtkCssProvider *provider;
   GError *error = NULL;
@@ -174,13 +130,13 @@ load_ui_file (GFile *file, gboolean generate)
   diff = diff_with_file (reference_file, output, -1, &error);
   g_assert_no_error (error);
 
-  if (diff && g_bytes_get_size (diff) > 0)
+  if (diff && diff[0])
     {
-      g_test_message ("Resulting output doesn't match reference:\n%s", (const char *) g_bytes_get_data (diff, NULL));
+      g_test_message ("Resulting output doesn't match reference:\n%s", diff);
       g_test_fail ();
     }
   g_free (reference_file);
-  g_clear_pointer (&diff, g_bytes_unref);
+  g_free (diff);
 
 out:
   gtk_style_context_remove_provider_for_display (gdk_display_get_default (),
